@@ -215,6 +215,8 @@ class LavalinkEvents(MixinMeta, metaclass=CompositeMetaClass):
                     await self.config.guild_from_id(
                         guild_id=guild_id
                     ).currently_auto_playing_in.set([])
+                    # let audio buffer run out on slower machines (GH-5158)
+                    await asyncio.sleep(2)
                     await player.disconnect()
                     self._ll_guild_updates.discard(guild.id)
             if status:
@@ -285,7 +287,9 @@ class LavalinkEvents(MixinMeta, metaclass=CompositeMetaClass):
                         embed = discord.Embed(
                             title=_("Track Error"),
                             colour=await self.bot.get_embed_color(message_channel),
-                            description="{}\n{}".format(extra.replace("\n", ""), description),
+                            description="{}\n{}".format(
+                                extra["message"].replace("\n", ""), description
+                            ),
                         )
                         if current_id:
                             asyncio.create_task(
