@@ -55,9 +55,10 @@ class Cleanup(commands.Cog):
             return True
 
         prompt = await ctx.send(
-            _("Are you sure you want to delete {number} messages? (y/n)").format(
+            _("Are you sure you want to delete {number} messages?").format(
                 number=humanize_number(number)
             )
+            + " (yes/no)"
         )
         response = await ctx.bot.wait_for("message", check=MessagePredicate.same_context(ctx))
 
@@ -731,6 +732,7 @@ class Cleanup(commands.Cog):
         """Manage the settings for the cleanup command."""
         pass
 
+    @commands.guild_only()
     @cleanupset.command(name="notify")
     async def cleanupset_notify(self, ctx: commands.Context):
         """Toggle clean up notification settings.
