@@ -90,7 +90,7 @@ def guild_only_check():
     async def pred(ctx: commands.Context):
         if await bank.is_global():
             return True
-        elif not await bank.is_global() and ctx.guild is not None:
+        elif ctx.guild is not None and not await bank.is_global():
             return True
         else:
             return False
@@ -415,8 +415,7 @@ class Economy(commands.Cog):
         - `<user>` The user to delete the bank of. Takes mentions, names, and user ids.
         - `<confirmation>` This will default to false unless specified.
         """
-        global_bank = await bank.is_global()
-        if global_bank is False and ctx.guild is None:
+        if ctx.guild is None and not await bank.is_global():
             return await ctx.send(_("This command cannot be used in DMs with a local bank."))
         try:
             name = member_or_id.display_name
@@ -580,7 +579,7 @@ class Economy(commands.Cog):
             top = 10
 
         base_embed = discord.Embed(title=_("Economy Leaderboard"))
-        if await bank.is_global() and show_global:
+        if show_global and await bank.is_global():
             # show_global is only applicable if bank is global
             bank_sorted = await bank.get_leaderboard(positions=top, guild=None)
             base_embed.set_author(name=ctx.bot.user.name, icon_url=ctx.bot.user.avatar_url)
@@ -817,15 +816,20 @@ class Economy(commands.Cog):
         """
         Shows the current economy settings
         """
+        role_paydays = []
         guild = ctx.guild
         if await bank.is_global():
             conf = self.config
         else:
             conf = self.config.guild(guild)
+            for role in guild.roles:
+                rolepayday = await self.config.role(role).PAYDAY_CREDITS()
+                if rolepayday:
+                    role_paydays.append(f"{role}: {rolepayday}")
         await ctx.send(
             box(
                 _(
-                    "----Economy Settings---\n"
+                    "---Economy Settings---\n"
                     "Minimum slot bid: {slot_min}\n"
                     "Maximum slot bid: {slot_max}\n"
                     "Slot cooldown: {slot_time}\n"
@@ -844,6 +848,8 @@ class Economy(commands.Cog):
                 )
             )
         )
+        if role_paydays:
+            await ctx.send(box(_("---Role Payday Amounts---\n") + "\n".join(role_paydays)))
 
     @economyset.command()
     async def slotmin(self, ctx: commands.Context, bid: positive_int):
@@ -998,6 +1004,7 @@ class Economy(commands.Cog):
     @economyset.command()
     async def rolepaydayamount(self, ctx: commands.Context, role: discord.Role, creds: int):
         """Set the amount earned each payday for a role.
+
         Set to `0` to remove the payday amount you set for that role.
 
         Only available when not using a global bank.
