@@ -40,7 +40,12 @@ class KickBanMixin(MixinMeta):
             if "VANITY_URL" in guild.features:
                 # guild has a vanity url so use it as the one to send
                 try:
-                    return await guild.vanity_invite()
+                    invite = await guild.vanity_invite()
+                    # `if` is needed to work around
+                    # https://github.com/Rapptz/discord.py/issues/7103
+                    # until we can use a version with the fix
+                    if invite.code is not None:
+                        return invite
                 except discord.NotFound:
                     # If a guild has the vanity url feature,
                     # but does not have it set up,
@@ -243,7 +248,7 @@ class KickBanMixin(MixinMeta):
         async for guild_id, guild_data in AsyncIter(guilds_data.items(), steps=100):
             if not (guild := self.bot.get_guild(guild_id)):
                 continue
-            if not guild.me.guild_permissions.ban_members:
+            if guild.unavailable or not guild.me.guild_permissions.ban_members:
                 continue
             if await self.bot.cog_disabled_in_guild(self, guild):
                 continue
@@ -296,7 +301,7 @@ class KickBanMixin(MixinMeta):
 
         Examples:
            - `[p]kick 428675506947227648 wanted to be kicked.`
-            This will kick Twentysix from the server.
+            This will kick the user with ID 428675506947227648 from the server.
            - `[p]kick @Twentysix wanted to be kicked.`
             This will kick Twentysix from the server.
 
@@ -382,7 +387,7 @@ class KickBanMixin(MixinMeta):
 
         Examples:
            - `[p]ban 428675506947227648 7 Continued to spam after told to stop.`
-            This will ban Twentysix and it will delete 7 days worth of messages.
+            This will ban the user with ID 428675506947227648 and it will delete 7 days worth of messages.
            - `[p]ban @Twentysix 7 Continued to spam after told to stop.`
             This will ban Twentysix and it will delete 7 days worth of messages.
 
@@ -597,7 +602,7 @@ class KickBanMixin(MixinMeta):
            - `[p]tempban @Twentysix 15m You need a timeout`
             This will ban Twentysix for 15 minutes.
            - `[p]tempban 428675506947227648 1d2h15m 5 Evil person`
-            This will ban the user for 1 day 2 hours 15 minutes and will delete the last 5 days of their messages.
+            This will ban the user with ID 428675506947227648 for 1 day 2 hours 15 minutes and will delete the last 5 days of their messages.
         """
         guild = ctx.guild
         author = ctx.author
@@ -620,12 +625,14 @@ class KickBanMixin(MixinMeta):
             await ctx.send(_("I cannot do that due to Discord hierarchy rules."))
             return
 
+        guild_data = await self.config.guild(guild).all()
+
         if duration is None:
-            duration = timedelta(seconds=await self.config.guild(guild).default_tempban_duration())
+            duration = timedelta(seconds=guild_data["default_tempban_duration"])
         unban_time = datetime.now(timezone.utc) + duration
 
         if days is None:
-            days = await self.config.guild(guild).default_days()
+            days = guild_data["default_days"]
 
         if not (0 <= days <= 7):
             await ctx.send(_("Invalid days. Must be between 0 and 7."))
@@ -641,10 +648,12 @@ class KickBanMixin(MixinMeta):
         with contextlib.suppress(discord.HTTPException):
             # We don't want blocked DMs preventing us from banning
             msg = _("You have been temporarily banned from {server_name} until {date}.").format(
-                server_name=guild.name, date=unban_time.strftime("%m-%d-%Y %H:%M:%S")
+                server_name=guild.name, date=f"<t:{int(unban_time.timestamp())}>"
             )
+            if guild_data["dm_on_kickban"] and reason:
+                msg += _("\n\n**Reason:** {reason}").format(reason=reason)
             if invite:
-                msg += _(" Here is an invite for when your ban expires: {invite_link}").format(
+                msg += _("\n\nHere is an invite for when your ban expires: {invite_link}").format(
                     invite_link=invite
                 )
             await member.send(msg)
@@ -798,6 +807,7 @@ class KickBanMixin(MixinMeta):
                 until=None,
                 channel=case_channel,
             )
+            await ctx.send(_("User has been kicked from the voice channel."))
 
     @commands.command()
     @commands.guild_only()
@@ -950,7 +960,7 @@ class KickBanMixin(MixinMeta):
                 except discord.HTTPException:
                     await ctx.send(
                         _(
-                            "Something went wrong when attempting to send that user"
+                            "Something went wrong when attempting to send that user "
                             "an invite. Here's the link so you can try: {invite_link}"
                         ).format(invite_link=invite.url)
                     )
