@@ -8,6 +8,7 @@ Some of the converters within are included provisionally and are marked as such.
 import functools
 import re
 from datetime import timedelta
+from dateutil.relativedelta import relativedelta
 from typing import (
     TYPE_CHECKING,
     Generic,
@@ -35,25 +36,30 @@ if TYPE_CHECKING:
 
 __all__ = [
     "DictConverter",
-    "GuildConverter",
     "UserInputOptional",
     "NoParseOptional",
+    "RelativedeltaConverter",
     "TimedeltaConverter",
     "get_dict_converter",
     "get_timedelta_converter",
+    "parse_relativedelta",
     "parse_timedelta",
     "Literal",
+    "CommandConverter",
+    "CogConverter",
 ]
 
 _ = Translator("commands.converter", __file__)
 
-ID_REGEX = re.compile(r"([0-9]{15,21})")
+ID_REGEX = re.compile(r"([0-9]{15,20})")
 
 
 # Taken with permission from
 # https://github.com/mikeshardmind/SinbadCogs/blob/816f3bc2ba860243f75112904b82009a8a9e1f99/scheduler/time_utils.py#L9-L19
 TIME_RE_STRING = r"\s?".join(
     [
+        r"((?P<years>\d+?)\s?(years?|y))?",
+        r"((?P<months>\d+?)\s?(months?|mo))?",
         r"((?P<weeks>\d+?)\s?(weeks?|w))?",
         r"((?P<days>\d+?)\s?(days?|d))?",
         r"((?P<hours>\d+?)\s?(hours?|hrs|hr?))?",
@@ -65,6 +71,22 @@ TIME_RE_STRING = r"\s?".join(
 TIME_RE = re.compile(TIME_RE_STRING, re.I)
 
 
+def _parse_and_match(string_to_match: str, allowed_units: List[str]) -> Optional[Dict[str, int]]:
+    """
+    Local utility function to match TIME_RE string above to user input for both parse_timedelta and parse_relativedelta
+    """
+    matches = TIME_RE.match(string_to_match)
+    if matches:
+        params = {k: int(v) for k, v in matches.groupdict().items() if v is not None}
+        for k in params.keys():
+            if k not in allowed_units:
+                raise BadArgument(
+                    _("`{unit}` is not a valid unit of time for this command").format(unit=k)
+                )
+        return params
+    return None
+
+
 def parse_timedelta(
     argument: str,
     *,
@@ -82,9 +104,9 @@ def parse_timedelta(
     ----------
     argument : str
         The user provided input
-    maximum : Optional[timedelta]
+    maximum : Optional[datetime.timedelta]
         If provided, any parsed value higher than this will raise an exception
-    minimum : Optional[timedelta]
+    minimum : Optional[datetime.timedelta]
         If provided, any parsed value lower than this will raise an exception
     allowed_units : Optional[List[str]]
         If provided, you can constrain a user to expressing the amount of time
@@ -93,7 +115,7 @@ def parse_timedelta(
 
     Returns
     -------
-    Optional[timedelta]
+    Optional[datetime.timedelta]
         If matched, the timedelta which was parsed. This can return `None`
 
     Raises
@@ -102,61 +124,127 @@ def parse_timedelta(
         If the argument passed uses a unit not allowed, but understood
         or if the value is out of bounds.
     """
-    matches = TIME_RE.match(argument)
-    allowed_units = allowed_units or ["weeks", "days", "hours", "minutes", "seconds"]
-    if matches:
-        params = {k: int(v) for k, v in matches.groupdict().items() if v is not None}
-        for k in params.keys():
-            if k not in allowed_units:
-                raise BadArgument(
-                    _("`{unit}` is not a valid unit of time for this command").format(unit=k)
-                )
-        if params:
-            try:
-                delta = timedelta(**params)
-            except OverflowError:
-                raise BadArgument(
-                    _("The time set is way too high, consider setting something reasonable.")
-                )
-            if maximum and maximum < delta:
-                raise BadArgument(
-                    _(
-                        "This amount of time is too large for this command. (Maximum: {maximum})"
-                    ).format(maximum=humanize_timedelta(timedelta=maximum))
-                )
-            if minimum and delta < minimum:
-                raise BadArgument(
-                    _(
-                        "This amount of time is too small for this command. (Minimum: {minimum})"
-                    ).format(minimum=humanize_timedelta(timedelta=minimum))
-                )
-            return delta
+    allowed_units = allowed_units or [
+        "weeks",
+        "days",
+        "hours",
+        "minutes",
+        "seconds",
+    ]
+    params = _parse_and_match(argument, allowed_units)
+    if params:
+        try:
+            delta = timedelta(**params)
+        except OverflowError:
+            raise BadArgument(
+                _("The time set is way too high, consider setting something reasonable.")
+            )
+        if maximum and maximum < delta:
+            raise BadArgument(
+                _(
+                    "This amount of time is too large for this command. (Maximum: {maximum})"
+                ).format(maximum=humanize_timedelta(timedelta=maximum))
+            )
+        if minimum and delta < minimum:
+            raise BadArgument(
+                _(
+                    "This amount of time is too small for this command. (Minimum: {minimum})"
+                ).format(minimum=humanize_timedelta(timedelta=minimum))
+            )
+        return delta
     return None
 
 
-class GuildConverter(discord.Guild):
+def parse_relativedelta(
+    argument: str, *, allowed_units: Optional[List[str]] = None
+) -> Optional[relativedelta]:
+    """
+    This converts a user provided string into a datetime with offset from NOW
+
+    The units should be in order from largest to smallest.
+    This works with or without whitespace.
+
+    Parameters
+    ----------
+    argument : str
+        The user provided input
+    allowed_units : Optional[List[str]]
+        If provided, you can constrain a user to expressing the amount of time
+        in specific units. The units you can chose to provide are the same as the
+        parser understands. (``years``, ``months``, ``weeks``, ``days``, ``hours``, ``minutes``, ``seconds``)
+
+    Returns
+    -------
+    Optional[dateutil.relativedelta.relativedelta]
+        If matched, the relativedelta which was parsed. This can return `None`
+
+    Raises
+    ------
+    BadArgument
+        If the argument passed uses a unit not allowed, but understood
+        or if the value is out of bounds.
+    """
+    allowed_units = allowed_units or [
+        "years",
+        "months",
+        "weeks",
+        "days",
+        "hours",
+        "minutes",
+        "seconds",
+    ]
+    params = _parse_and_match(argument, allowed_units)
+    if params:
+        try:
+            delta = relativedelta(**params)
+        except OverflowError:
+            raise BadArgument(
+                _("The time set is way too high, consider setting something reasonable.")
+            )
+        return delta
+    return None
+
+
+class _GuildConverter(discord.Guild):
     """Converts to a `discord.Guild` object.
 
     The lookup strategy is as follows (in order):
 
     1. Lookup by ID.
     2. Lookup by name.
+
+    .. deprecated-removed:: 3.4.8 60
+        ``GuildConverter`` is now only provided within ``redbot.core.commands`` namespace.
     """
 
     @classmethod
     async def convert(cls, ctx: "Context", argument: str) -> discord.Guild:
-        match = ID_REGEX.fullmatch(argument)
+        return await dpy_commands.GuildConverter().convert(ctx, argument)
 
-        if match is None:
-            ret = discord.utils.get(ctx.bot.guilds, name=argument)
-        else:
-            guild_id = int(match.group(1))
-            ret = ctx.bot.get_guild(guild_id)
 
-        if ret is None:
-            raise BadArgument(_('Server "{name}" not found.').format(name=argument))
+_GuildConverter.__name__ = "GuildConverter"
 
-        return ret
+
+def __getattr__(name: str, *, stacklevel: int = 2) -> Any:
+    # Let me just say it one more time... This is awesome! (PEP-562)
+    if name == "GuildConverter":
+        # let's not waste time on importing this when we don't need it
+        # (and let's not put in the public API)
+        from redbot.core.utils._internal_utils import deprecated_removed
+
+        deprecated_removed(
+            "`GuildConverter` from `redbot.core.commands.converter` namespace",
+            "3.4.8",
+            60,
+            "Use `GuildConverter` from `redbot.core.commands` namespace instead.",
+            stacklevel=2,
+        )
+        return globals()["_GuildConverter"]
+    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
+
+
+def __dir__() -> List[str]:
+    return [*globals().keys(), "GuildConverter"]
 
 
 # Below this line are a lot of lies for mypy about things that *end up* correct when
@@ -234,9 +322,9 @@ else:
 
         Attributes
         ----------
-        maximum : Optional[timedelta]
+        maximum : Optional[datetime.timedelta]
             If provided, any parsed value higher than this will raise an exception
-        minimum : Optional[timedelta]
+        minimum : Optional[datetime.timedelta]
             If provided, any parsed value lower than this will raise an exception
         allowed_units : Optional[List[str]]
             If provided, you can constrain a user to expressing the amount of time
@@ -299,9 +387,9 @@ else:
 
         Parameters
         ----------
-        maximum : Optional[timedelta]
+        maximum : Optional[datetime.timedelta]
             If provided, any parsed value higher than this will raise an exception
-        minimum : Optional[timedelta]
+        minimum : Optional[datetime.timedelta]
             If provided, any parsed value lower than this will raise an exception
         allowed_units : Optional[List[str]]
             If provided, you can constrain a user to expressing the amount of time
@@ -333,6 +421,46 @@ else:
         return ValidatedConverter
 
 
+if TYPE_CHECKING:
+    RelativedeltaConverter = relativedelta
+else:
+
+    class RelativedeltaConverter(dpy_commands.Converter):
+        """
+        This is a converter for relative deltas.
+
+        The units should be in order from largest to smallest.
+        This works with or without whitespace.
+
+        See `parse_relativedelta` for more information about how this functions.
+
+        Attributes
+        ----------
+        allowed_units : Optional[List[str]]
+            If provided, you can constrain a user to expressing the amount of time
+            in specific units. The units you can choose to provide are the same as the
+            parser understands: (``years``, ``months``, ``weeks``, ``days``, ``hours``, ``minutes``, ``seconds``)
+        default_unit : Optional[str]
+            If provided, it will additionally try to match integer-only input into
+            a timedelta, using the unit specified. Same units as in ``allowed_units``
+            apply.
+        """
+
+        def __init__(self, *, allowed_units=None, default_unit=None):
+            self.allowed_units = allowed_units
+            self.default_unit = default_unit
+
+        async def convert(self, ctx: "Context", argument: str) -> relativedelta:
+            if self.default_unit and argument.isdecimal():
+                argument = argument + self.default_unit
+
+            delta = parse_relativedelta(argument, allowed_units=self.allowed_units)
+
+            if delta is not None:
+                return delta
+            raise BadArgument()  # This allows this to be a required argument.
+
+
 if not TYPE_CHECKING:
 
     class NoParseOptional:
@@ -400,3 +528,29 @@ if not TYPE_CHECKING:
                 return cls(k)
             else:
                 return cls((k,))
+
+
+if TYPE_CHECKING:
+    CommandConverter = dpy_commands.Command
+    CogConverter = dpy_commands.Cog
+else:
+
+    class CommandConverter(dpy_commands.Converter):
+        """Converts a command name to the matching `redbot.core.commands.Command` object."""
+
+        async def convert(self, ctx: "Context", argument: str):
+            arg = argument.strip()
+            command = ctx.bot.get_command(arg)
+            if not command:
+                raise BadArgument(_('Command "{arg}" not found.').format(arg=arg))
+            return command
+
+    class CogConverter(dpy_commands.Converter):
+        """Converts a cog name to the matching `redbot.core.commands.Cog` object."""
+
+        async def convert(self, ctx: "Context", argument: str):
+            arg = argument.strip()
+            cog = ctx.bot.get_cog(arg)
+            if not cog:
+                raise BadArgument(_('Cog "{arg}" not found.').format(arg=arg))
+            return cog
